@@ -19,6 +19,7 @@ test_that("row eq col on matrix xs and ys", {
   expect_equal(row_oneway_equalvar(X, g), col_oneway_equalvar(t(X), g))
   expect_equal(row_oneway_welch(X, g), col_oneway_welch(t(X), g))
   expect_equal(row_kruskalwallis(X, g), col_kruskalwallis(t(X), g))
+  expect_equal(row_waerden(X, g), col_waerden(t(X), g))
   expect_equal(row_bartlett(X, g), col_bartlett(t(X), g))
   expect_equal(row_flignerkilleen(X, g), col_flignerkilleen(t(X), g))
   expect_equal(row_levene(X, g), col_levene(t(X), g))
@@ -47,6 +48,7 @@ test_that("row eq col on data.frame xs and ys", {
   expect_equal(row_oneway_equalvar(X, g), col_oneway_equalvar(t(X), g))
   expect_equal(row_oneway_welch(X, g), col_oneway_welch(t(X), g))
   expect_equal(row_kruskalwallis(X, g), col_kruskalwallis(t(X), g))
+  expect_equal(row_waerden(X, g), col_waerden(t(X), g))
   expect_equal(row_bartlett(X, g), col_bartlett(t(X), g))
   expect_equal(row_flignerkilleen(X, g), col_flignerkilleen(t(X), g))
   expect_equal(row_levene(X, g), col_levene(t(X), g))
@@ -75,6 +77,7 @@ test_that("row eq col on vector xs and ys", {
   expect_equal(row_oneway_equalvar(X, g), col_oneway_equalvar(X, g))
   expect_equal(row_oneway_welch(X, g), col_oneway_welch(X, g))
   expect_equal(row_kruskalwallis(X, g), col_kruskalwallis(X, g))
+  expect_equal(row_waerden(X, g), col_waerden(X, g))
   expect_equal(row_bartlett(X, g), col_bartlett(X, g))
   expect_equal(row_flignerkilleen(X, g), col_flignerkilleen(X, g))
   expect_equal(row_levene(X, g), col_levene(X, g))
@@ -103,6 +106,7 @@ test_that("row eq col on 0 dimension matrix xs and ys", {
   expect_equal(row_oneway_equalvar(X, g), col_oneway_equalvar(X, g))
   expect_equal(row_oneway_welch(X, g), col_oneway_welch(X, g))
   expect_equal(row_kruskalwallis(X, g), col_kruskalwallis(X, g))
+  expect_equal(row_waerden(X, g), col_waerden(X, g))
   expect_equal(row_bartlett(X, g), col_bartlett(X, g))
   expect_equal(row_flignerkilleen(X, g), col_flignerkilleen(X, g))
   expect_equal(row_levene(X, g), col_levene(X, g))
